/******************************************************************************
 * @file     gpio.h
 * @brief    GPIO driver header file.
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/


#ifndef GPIO_H
#define GPIO_H

#ifdef __cplusplus
extern "C" {
#endif


#include "spc2168.h"




/**
 *  @brief  GPIO Pinmux channel type definition
 */
typedef enum
{
    PINMUX_CHANNEL_0      = 0,                /*!< GPIO pin mux channel 0 define */
    PINMUX_CHANNEL_1      = 1,                /*!< GPIO pin mux channel 1 define */
    PINMUX_CHANNEL_2      = 2,                /*!< GPIO pin mux channel 2 define */
    PINMUX_CHANNEL_3      = 3,                /*!< GPIO pin mux channel 3 define */
    PINMUX_CHANNEL_4      = 4,                /*!< GPIO pin mux channel 4 define */
    PINMUX_CHANNEL_5      = 5,                /*!< GPIO pin mux channel 5 define */
    PINMUX_CHANNEL_6      = 6,                /*!< GPIO pin mux channel 6 define */
    PINMUX_CHANNEL_7      = 7,                /*!< GPIO pin mux channel 7 define */
} GPIO_PinMuxChannelEnum;




/**
 *  @brief  GPIO data direction type definition
 */
typedef enum
{
    GPIO_INPUT            = 0,                /*!< Set GPIO port data direction as input  */
    GPIO_OUTPUT           = 1,                /*!< Set GPIO port data direction as output */
} GPIO_DirEnum;




/**
 *  @brief  GPIO data Input/Output type definition
 */
typedef enum
{
    GPIO_LEVEL_LOW        = 0,                /*!< Set GPIO port data Input/Output value as LOW  */
    GPIO_LEVEL_HIGH       = 1,                /*!< Set GPIO port data Input/Output value as HIGH */
} GPIO_LevelEnum;




/**
 *  @brief  GPIO edge detection type definition
 */
typedef enum
{
    GPIO_INT_RISING_EDGE  = 0,                /*!< Rising edge detection                  */
    GPIO_INT_FALLING_EDGE = 1,                /*!< Falling edge detection                 */
    GPIO_INT_BOTH_EDGES   = 2,                /*!< Rising edge and Falling edge detection */
    GPIO_INT_IGNORE_EDGE  = 3,                /*!< Disable edge detection                 */
} GPIO_EdgeIntEnum;




/**
 *  @brief  GPIO output driving strength type definition
 */
typedef enum
{
    GPIO_OUT_STRENGTH_5MA  = 0,               /*!< Output strength is 5  mA               */
    GPIO_OUT_STRENGTH_10MA = 1,               /*!< Output strength is 10 mA               */
    GPIO_OUT_STRENGTH_15MA = 2,               /*!< Output strength is 15 mA               */
    GPIO_OUT_STRENGTH_20MA = 3,               /*!< Output strength is 20 mA               */
} GPIO_OutStrengthEnum;




/**
 *  @brief  GPIO0 pinmux function define
 */
#define GPIO0_GPIO0               PINMUX_CHANNEL_0
#define GPIO0_ADC0                PINMUX_CHANNEL_1
#define GPIO0_COMP0H              PINMUX_CHANNEL_2
#define GPIO0_SIO0_0              PINMUX_CHANNEL_6
#define GPIO0_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO1 pinmux function define
 */
#define GPIO1_GPIO1               PINMUX_CHANNEL_0
#define GPIO1_ADC1                PINMUX_CHANNEL_1
#define GPIO1_COMP0L              PINMUX_CHANNEL_2
#define GPIO1_SIO0_1              PINMUX_CHANNEL_6
#define GPIO1_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO2 pinmux function define
 */
#define GPIO2_GPIO2               PINMUX_CHANNEL_0
#define GPIO2_ADC2                PINMUX_CHANNEL_1
#define GPIO2_COMP1H              PINMUX_CHANNEL_2
#define GPIO2_SIO0_2              PINMUX_CHANNEL_6
#define GPIO2_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO3 pinmux function define
 */
#define GPIO3_GPIO3               PINMUX_CHANNEL_0
#define GPIO3_ADC3                PINMUX_CHANNEL_1
#define GPIO3_COMP1L              PINMUX_CHANNEL_2
#define GPIO3_SIO0_3              PINMUX_CHANNEL_6
#define GPIO3_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO4 pinmux function define
 */
#define GPIO4_GPIO4               PINMUX_CHANNEL_0
#define GPIO4_ADC4                PINMUX_CHANNEL_1
#define GPIO4_COMP2H              PINMUX_CHANNEL_2
#define GPIO4_SIO0_4              PINMUX_CHANNEL_6
#define GPIO4_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO5 pinmux function define
 */
#define GPIO5_GPIO5               PINMUX_CHANNEL_0
#define GPIO5_ADC5                PINMUX_CHANNEL_1
#define GPIO5_COMP2L              PINMUX_CHANNEL_2
#define GPIO5_SIO0_5              PINMUX_CHANNEL_6
#define GPIO5_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO6 pinmux function define
 */
#define GPIO6_GPIO6               PINMUX_CHANNEL_0
#define GPIO6_ADC6                PINMUX_CHANNEL_1
#define GPIO6_SIO0_6              PINMUX_CHANNEL_6
#define GPIO6_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO7 pinmux function define
 */
#define GPIO7_GPIO7               PINMUX_CHANNEL_0
#define GPIO7_ADC7                PINMUX_CHANNEL_1
#define GPIO7_SIO0_7              PINMUX_CHANNEL_6
#define GPIO7_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO8 pinmux function define
 */
#define GPIO8_GPIO8               PINMUX_CHANNEL_0
#define GPIO8_ADC8                PINMUX_CHANNEL_1
#define GPIO8_SIO0_8              PINMUX_CHANNEL_6
#define GPIO8_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO9 pinmux function define
 */
#define GPIO9_GPIO9               PINMUX_CHANNEL_0
#define GPIO9_ADC9                PINMUX_CHANNEL_1
#define GPIO9_SIO0_9              PINMUX_CHANNEL_6
#define GPIO9_ECAPO               PINMUX_CHANNEL_7




/**
 *  @brief  GPIO10 pinmux function define
 */
#define GPIO10_GPIO10             PINMUX_CHANNEL_0
#define GPIO10_ADC10              PINMUX_CHANNEL_1
#define GPIO10_COMP3H             PINMUX_CHANNEL_2
#define GPIO10_SIO0_10            PINMUX_CHANNEL_6
#define GPIO10_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO11 pinmux function define
 */
#define GPIO11_GPIO11             PINMUX_CHANNEL_0
#define GPIO11_ADC11              PINMUX_CHANNEL_1
#define GPIO11_COMP3L             PINMUX_CHANNEL_2
#define GPIO11_SIO0_11            PINMUX_CHANNEL_6
#define GPIO11_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO12 pinmux function define
 */
#define GPIO12_GPIO12             PINMUX_CHANNEL_0
#define GPIO12_ADC12              PINMUX_CHANNEL_1
#define GPIO12_COMP4H             PINMUX_CHANNEL_2
#define GPIO12_SIO0_12            PINMUX_CHANNEL_6
#define GPIO12_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO13 pinmux function define
 */
#define GPIO13_GPIO13             PINMUX_CHANNEL_0
#define GPIO13_ADC13              PINMUX_CHANNEL_1
#define GPIO13_COMP4L             PINMUX_CHANNEL_2
#define GPIO13_SIO0_13            PINMUX_CHANNEL_6
#define GPIO13_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO14 pinmux function define
 */
#define GPIO14_GPIO14             PINMUX_CHANNEL_0
#define GPIO14_ADC14              PINMUX_CHANNEL_1
#define GPIO14_COMP5H             PINMUX_CHANNEL_2
#define GPIO14_SIO0_14            PINMUX_CHANNEL_6
#define GPIO14_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO15 pinmux function define
 */
#define GPIO15_GPIO15             PINMUX_CHANNEL_0
#define GPIO15_ADC15              PINMUX_CHANNEL_1
#define GPIO15_COMP5L             PINMUX_CHANNEL_2
#define GPIO15_SIO0_15            PINMUX_CHANNEL_6
#define GPIO15_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO16 pinmux function define
 */
#define GPIO16_GPIO16             PINMUX_CHANNEL_0
#define GPIO16_ADC16              PINMUX_CHANNEL_1
#define GPIO16_COMP6H             PINMUX_CHANNEL_2
#define GPIO16_SIO0_16            PINMUX_CHANNEL_6
#define GPIO16_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO17 pinmux function define
 */
#define GPIO17_GPIO17             PINMUX_CHANNEL_0
#define GPIO17_ADC17              PINMUX_CHANNEL_1
#define GPIO17_COMP6L             PINMUX_CHANNEL_2
#define GPIO17_SIO0_17            PINMUX_CHANNEL_6
#define GPIO17_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO18 pinmux function define
 */
#define GPIO18_GPIO18             PINMUX_CHANNEL_0
#define GPIO18_ADC18              PINMUX_CHANNEL_1
#define GPIO18_COMP7H             PINMUX_CHANNEL_2
#define GPIO18_SIO0_0             PINMUX_CHANNEL_6
#define GPIO18_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO19 pinmux function define
 */
#define GPIO19_GPIO19             PINMUX_CHANNEL_0
#define GPIO19_ADC19              PINMUX_CHANNEL_1
#define GPIO19_COMP7L             PINMUX_CHANNEL_2
#define GPIO19_SIO0_1             PINMUX_CHANNEL_6
#define GPIO19_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO20 pinmux function define
 */
#define GPIO20_GPIO20             PINMUX_CHANNEL_0
#define GPIO20_XIN                PINMUX_CHANNEL_1
#define GPIO20_SPI_SCLK           PINMUX_CHANNEL_2
#define GPIO20_I2C_SCL            PINMUX_CHANNEL_3
#define GPIO20_UART_TXD           PINMUX_CHANNEL_4
#define GPIO20_PWMSYNCO           PINMUX_CHANNEL_5
#define GPIO20_SIO0_2             PINMUX_CHANNEL_6
#define GPIO20_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO21 pinmux function define
 */
#define GPIO21_GPIO21             PINMUX_CHANNEL_0
#define GPIO21_XIO                PINMUX_CHANNEL_1
#define GPIO21_SPI_SFRM           PINMUX_CHANNEL_2
#define GPIO21_I2C_SDA            PINMUX_CHANNEL_3
#define GPIO21_UART_RXD           PINMUX_CHANNEL_4
#define GPIO21_PWMSOC             PINMUX_CHANNEL_5
#define GPIO21_SIO0_3             PINMUX_CHANNEL_6
#define GPIO21_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO22 pinmux function define
 */
#define GPIO22_GPIO22             PINMUX_CHANNEL_0
#define GPIO22_SPI_MOSI           PINMUX_CHANNEL_2
#define GPIO22_SPI_MISO           PINMUX_CHANNEL_3
#define GPIO22_SIO0_4             PINMUX_CHANNEL_6
#define GPIO22_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO23 pinmux function define
 */
#define GPIO23_GPIO23             PINMUX_CHANNEL_0
#define GPIO23_SPI_MISO           PINMUX_CHANNEL_2
#define GPIO23_SPI_MOSI           PINMUX_CHANNEL_3
#define GPIO23_SIO0_5             PINMUX_CHANNEL_6
#define GPIO23_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO24 pinmux function define
 */
#define GPIO24_GPIO24             PINMUX_CHANNEL_0
#define GPIO24_COMP0H             PINMUX_CHANNEL_2
#define GPIO24_PWM1A              PINMUX_CHANNEL_4
#define GPIO24_SIO0_6             PINMUX_CHANNEL_6
#define GPIO24_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO25 pinmux function define
 */
#define GPIO25_GPIO25             PINMUX_CHANNEL_0
#define GPIO25_COMP0L             PINMUX_CHANNEL_2
#define GPIO25_PWM2A              PINMUX_CHANNEL_4
#define GPIO25_PWM1B              PINMUX_CHANNEL_5
#define GPIO25_SIO0_7             PINMUX_CHANNEL_6
#define GPIO25_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO26 pinmux function define
 */
#define GPIO26_GPIO26             PINMUX_CHANNEL_0
#define GPIO26_COMP1H             PINMUX_CHANNEL_2
#define GPIO26_PWM3A              PINMUX_CHANNEL_4
#define GPIO26_PWM2A              PINMUX_CHANNEL_5
#define GPIO26_SIO1_0             PINMUX_CHANNEL_6
#define GPIO26_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO27 pinmux function define
 */
#define GPIO27_GPIO27             PINMUX_CHANNEL_0
#define GPIO27_COMP1L             PINMUX_CHANNEL_2
#define GPIO27_PWM1B              PINMUX_CHANNEL_4
#define GPIO27_PWM2B              PINMUX_CHANNEL_5
#define GPIO27_SIO1_1             PINMUX_CHANNEL_6
#define GPIO27_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO28 pinmux function define
 */
#define GPIO28_GPIO28             PINMUX_CHANNEL_0
#define GPIO28_COMP2H             PINMUX_CHANNEL_2
#define GPIO28_PWM2B              PINMUX_CHANNEL_4
#define GPIO28_PWM3A              PINMUX_CHANNEL_5
#define GPIO28_SIO1_2             PINMUX_CHANNEL_6
#define GPIO28_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO29 pinmux function define
 */
#define GPIO29_GPIO29             PINMUX_CHANNEL_0
#define GPIO29_COMP2L             PINMUX_CHANNEL_2
#define GPIO29_PWM3B              PINMUX_CHANNEL_4
#define GPIO29_SIO1_3             PINMUX_CHANNEL_6
#define GPIO29_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO30 pinmux function define
 */
#define GPIO30_GPIO30             PINMUX_CHANNEL_0
#define GPIO30_I2C_SCL            PINMUX_CHANNEL_1
#define GPIO30_SIO1_4             PINMUX_CHANNEL_6
#define GPIO30_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO31 pinmux function define
 */
#define GPIO31_GPIO31             PINMUX_CHANNEL_0
#define GPIO31_I2C_SDA            PINMUX_CHANNEL_1
#define GPIO31_SIO1_5             PINMUX_CHANNEL_6
#define GPIO31_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO32 pinmux function define
 */
#define GPIO32_GPIO32             PINMUX_CHANNEL_0
#define GPIO32_COMP3H             PINMUX_CHANNEL_2
#define GPIO32_PWMSYNCO           PINMUX_CHANNEL_3
#define GPIO32_PWM4A              PINMUX_CHANNEL_4
#define GPIO32_SIO1_6             PINMUX_CHANNEL_6
#define GPIO32_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO33 pinmux function define
 */
#define GPIO33_GPIO33             PINMUX_CHANNEL_0
#define GPIO33_COMP3L             PINMUX_CHANNEL_2
#define GPIO33_PWMSOC             PINMUX_CHANNEL_3
#define GPIO33_PWM5A              PINMUX_CHANNEL_4
#define GPIO33_PWM4B              PINMUX_CHANNEL_5
#define GPIO33_SIO1_7             PINMUX_CHANNEL_6
#define GPIO33_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO34 pinmux function define
 */
#define GPIO34_GPIO34             PINMUX_CHANNEL_0
#define GPIO34_COMP4H             PINMUX_CHANNEL_2
#define GPIO34_PWM0A              PINMUX_CHANNEL_3
#define GPIO34_PWM6A              PINMUX_CHANNEL_4
#define GPIO34_PWM5A              PINMUX_CHANNEL_5
#define GPIO34_SIO1_8             PINMUX_CHANNEL_6
#define GPIO34_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO35 pinmux function define
 */
#define GPIO35_GPIO35             PINMUX_CHANNEL_0
#define GPIO35_COMP4L             PINMUX_CHANNEL_2
#define GPIO35_PWM0B              PINMUX_CHANNEL_3
#define GPIO35_PWM4B              PINMUX_CHANNEL_4
#define GPIO35_PWM5B              PINMUX_CHANNEL_5
#define GPIO35_SIO1_9             PINMUX_CHANNEL_6
#define GPIO35_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO36 pinmux function define
 */
#define GPIO36_GPIO36             PINMUX_CHANNEL_0
#define GPIO36_COMP5H             PINMUX_CHANNEL_2
#define GPIO36_PWM7A              PINMUX_CHANNEL_3
#define GPIO36_PWM5B              PINMUX_CHANNEL_4
#define GPIO36_PWM6A              PINMUX_CHANNEL_5
#define GPIO36_SIO1_10            PINMUX_CHANNEL_6
#define GPIO36_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO37 pinmux function define
 */
#define GPIO37_GPIO37             PINMUX_CHANNEL_0
#define GPIO37_COMP5L             PINMUX_CHANNEL_2
#define GPIO37_PWM7B              PINMUX_CHANNEL_3
#define GPIO37_PWM6B              PINMUX_CHANNEL_4
#define GPIO37_SIO1_11            PINMUX_CHANNEL_6
#define GPIO37_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO38 pinmux function define
 */
#define GPIO38_GPIO38             PINMUX_CHANNEL_0
#define GPIO38_SPI_SCLK           PINMUX_CHANNEL_1
#define GPIO38_UART_TXD           PINMUX_CHANNEL_2
#define GPIO38_UART_RXD           PINMUX_CHANNEL_3
#define GPIO38_PWMSOCA            PINMUX_CHANNEL_4
#define GPIO38_SIO1_12            PINMUX_CHANNEL_6
#define GPIO38_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO39 pinmux function define
 */
#define GPIO39_GPIO39             PINMUX_CHANNEL_0
#define GPIO39_SPI_SFRM           PINMUX_CHANNEL_1
#define GPIO39_UART_RXD           PINMUX_CHANNEL_2
#define GPIO39_UART_TXD           PINMUX_CHANNEL_3
#define GPIO39_PWMSOCB            PINMUX_CHANNEL_4
#define GPIO39_SIO1_13            PINMUX_CHANNEL_6
#define GPIO39_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO40 pinmux function define
 */
#define GPIO40_GPIO40             PINMUX_CHANNEL_0
#define GPIO40_SPI_MOSI           PINMUX_CHANNEL_1
#define GPIO40_SPI_MISO           PINMUX_CHANNEL_2
#define GPIO40_I2C_SCL            PINMUX_CHANNEL_3
#define GPIO40_PWMSOCC            PINMUX_CHANNEL_4
#define GPIO40_SIO1_14            PINMUX_CHANNEL_6
#define GPIO40_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO41 pinmux function define
 */
#define GPIO41_GPIO41             PINMUX_CHANNEL_0
#define GPIO41_SPI_MISO           PINMUX_CHANNEL_1
#define GPIO41_SPI_MOSI           PINMUX_CHANNEL_2
#define GPIO41_I2C_SDA            PINMUX_CHANNEL_3
#define GPIO41_PWMSYNCO           PINMUX_CHANNEL_4
#define GPIO41_SIO1_15            PINMUX_CHANNEL_6
#define GPIO41_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO42 pinmux function define
 */
#define GPIO42_GPIO42             PINMUX_CHANNEL_0
#define GPIO42_I2C_SCL            PINMUX_CHANNEL_1
#define GPIO42_COMP6H             PINMUX_CHANNEL_3
#define GPIO42_SPI_SCLK           PINMUX_CHANNEL_4
#define GPIO42_SIO1_16            PINMUX_CHANNEL_6
#define GPIO42_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO43 pinmux function define
 */
#define GPIO43_GPIO43             PINMUX_CHANNEL_0
#define GPIO43_I2C_SDA            PINMUX_CHANNEL_1
#define GPIO43_COMP6L             PINMUX_CHANNEL_3
#define GPIO43_SPI_SFRM           PINMUX_CHANNEL_4
#define GPIO43_SIO1_17            PINMUX_CHANNEL_6
#define GPIO43_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO44 pinmux function define
 */
#define GPIO44_GPIO44             PINMUX_CHANNEL_0
#define GPIO44_UART_TXD           PINMUX_CHANNEL_1
#define GPIO44_UART_RXD           PINMUX_CHANNEL_2
#define GPIO44_COMP7H             PINMUX_CHANNEL_3
#define GPIO44_SPI_MOSI           PINMUX_CHANNEL_4
#define GPIO44_SPI_MISO           PINMUX_CHANNEL_5
#define GPIO44_SIO2_0             PINMUX_CHANNEL_6
#define GPIO44_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO45 pinmux function define
 */
#define GPIO45_GPIO45             PINMUX_CHANNEL_0
#define GPIO45_UART_RXD           PINMUX_CHANNEL_1
#define GPIO45_UART_TXD           PINMUX_CHANNEL_2
#define GPIO45_COMP7L             PINMUX_CHANNEL_3
#define GPIO45_SPI_MISO           PINMUX_CHANNEL_4
#define GPIO45_SPI_MOSI           PINMUX_CHANNEL_5
#define GPIO45_SIO2_1             PINMUX_CHANNEL_6
#define GPIO45_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO46 pinmux function define
 */
#define GPIO46_GPIO46             PINMUX_CHANNEL_0
#define GPIO46_SIO2_2             PINMUX_CHANNEL_6
#define GPIO46_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO47 pinmux function define
 */
#define GPIO47_GPIO47             PINMUX_CHANNEL_0
#define GPIO47_SIO2_3             PINMUX_CHANNEL_6
#define GPIO47_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO48 pinmux function define
 */
#define GPIO48_GPIO48             PINMUX_CHANNEL_0
#define GPIO48_TCK                PINMUX_CHANNEL_1
#define GPIO48_SWCK               PINMUX_CHANNEL_1
#define GPIO48_COMP0H             PINMUX_CHANNEL_4
#define GPIO48_COMP3H             PINMUX_CHANNEL_5
#define GPIO48_SIO2_4             PINMUX_CHANNEL_6
#define GPIO48_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO49 pinmux function define
 */
#define GPIO49_GPIO49             PINMUX_CHANNEL_0
#define GPIO49_TMS                PINMUX_CHANNEL_1
#define GPIO49_SWD                PINMUX_CHANNEL_1
#define GPIO49_COMP0L             PINMUX_CHANNEL_4
#define GPIO49_COMP3L             PINMUX_CHANNEL_5
#define GPIO49_SIO2_5             PINMUX_CHANNEL_6
#define GPIO49_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO50 pinmux function define
 */
#define GPIO50_GPIO50             PINMUX_CHANNEL_0
#define GPIO50_TDI                PINMUX_CHANNEL_1
#define GPIO50_CAU_SWCK           PINMUX_CHANNEL_2
#define GPIO50_COMP1H             PINMUX_CHANNEL_4
#define GPIO50_COMP4H             PINMUX_CHANNEL_5
#define GPIO50_SIO2_6             PINMUX_CHANNEL_6
#define GPIO50_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO51 pinmux function define
 */
#define GPIO51_GPIO51             PINMUX_CHANNEL_0
#define GPIO51_TDO                PINMUX_CHANNEL_1
#define GPIO51_CAU_SWD            PINMUX_CHANNEL_2
#define GPIO51_COMP1L             PINMUX_CHANNEL_4
#define GPIO51_COMP4L             PINMUX_CHANNEL_5
#define GPIO51_SIO2_7             PINMUX_CHANNEL_6
#define GPIO51_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO52 pinmux function define
 */
#define GPIO52_GPIO52             PINMUX_CHANNEL_0
#define GPIO52_PWM0A              PINMUX_CHANNEL_3
#define GPIO52_COMP2H             PINMUX_CHANNEL_4
#define GPIO52_COMP5H             PINMUX_CHANNEL_5
#define GPIO52_SIO2_8             PINMUX_CHANNEL_6
#define GPIO52_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO53 pinmux function define
 */
#define GPIO53_GPIO53             PINMUX_CHANNEL_0
#define GPIO53_PWM0B              PINMUX_CHANNEL_3
#define GPIO53_COMP2L             PINMUX_CHANNEL_4
#define GPIO53_COMP5L             PINMUX_CHANNEL_5
#define GPIO53_SIO2_9             PINMUX_CHANNEL_6
#define GPIO53_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO54 pinmux function define
 */
#define GPIO54_GPIO54             PINMUX_CHANNEL_0
#define GPIO54_PWM7A              PINMUX_CHANNEL_3
#define GPIO54_PWM4A              PINMUX_CHANNEL_4
#define GPIO54_SIO2_10            PINMUX_CHANNEL_6
#define GPIO54_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO55 pinmux function define
 */
#define GPIO55_GPIO55             PINMUX_CHANNEL_0
#define GPIO55_PWM7B              PINMUX_CHANNEL_3
#define GPIO55_PWM5A              PINMUX_CHANNEL_4
#define GPIO55_PWM4B              PINMUX_CHANNEL_5
#define GPIO55_SIO2_11            PINMUX_CHANNEL_6
#define GPIO55_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO56 pinmux function define
 */
#define GPIO56_GPIO56             PINMUX_CHANNEL_0
#define GPIO56_PWM4A              PINMUX_CHANNEL_4
#define GPIO56_SIO2_12            PINMUX_CHANNEL_6
#define GPIO56_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO57 pinmux function define
 */
#define GPIO57_GPIO57             PINMUX_CHANNEL_0
#define GPIO57_PWM5A              PINMUX_CHANNEL_4
#define GPIO57_PWM4B              PINMUX_CHANNEL_5
#define GPIO57_SIO2_13            PINMUX_CHANNEL_6
#define GPIO57_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO58 pinmux function define
 */
#define GPIO58_GPIO58             PINMUX_CHANNEL_0
#define GPIO58_PWM6A              PINMUX_CHANNEL_4
#define GPIO58_PWM5A              PINMUX_CHANNEL_5
#define GPIO58_SIO2_14            PINMUX_CHANNEL_6
#define GPIO58_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO59 pinmux function define
 */
#define GPIO59_GPIO59             PINMUX_CHANNEL_0
#define GPIO59_PWM4B              PINMUX_CHANNEL_4
#define GPIO59_PWM5B              PINMUX_CHANNEL_5
#define GPIO59_SIO2_15            PINMUX_CHANNEL_6
#define GPIO59_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO60 pinmux function define
 */
#define GPIO60_GPIO60             PINMUX_CHANNEL_0
#define GPIO60_PWM5B              PINMUX_CHANNEL_4
#define GPIO60_PWM6A              PINMUX_CHANNEL_5
#define GPIO60_SIO2_16            PINMUX_CHANNEL_6
#define GPIO60_ECAPO              PINMUX_CHANNEL_7




/**
 *  @brief  GPIO61 pinmux function define
 */
#define GPIO61_GPIO61             PINMUX_CHANNEL_0
#define GPIO61_PWM6B              PINMUX_CHANNEL_4
#define GPIO61_SIO2_17            PINMUX_CHANNEL_6
#define GPIO61_ECAPO              PINMUX_CHANNEL_7




/******************************************************************************
 * @brief      Get GPIO pin port and index
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define __GPIO_PIN_PORT(ePinNum)                ((ePinNum) >> (5U))
#define __GPIO_PIN_INDEX(ePinNum)               ((ePinNum) & (0x1FU))




/******************************************************************************
 * @brief      GPIO Pin Configuration Register define
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define PINMUX_GPIO(ePinNum)                ((__IO GPIO0_REG*)(PINMUX_BASE + ((ePinNum) * 4)))




/******************************************************************************
 * @brief      Set GPIO pin channel
 *
 * @param[in]  ePinNum :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eChannel:  GPIO pin channel, should be GPIO_PinMuxChannelEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_SetPinChannel(ePinNum,eChannel)    (PINMUX_GPIO(ePinNum)->bit.MUXSEL = (eChannel & 0x07))




/******************************************************************************
 * @brief      Set GPIO output strength
 *
 * @param[in]  ePinNum  :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eStrength:  GPIO output strength, should be GPIO_OutStrengthEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_SetOutStrength(ePinNum,eStrength)  (PINMUX_GPIO(ePinNum)->bit.STRENGTH = (eStrength & 0x3))




/******************************************************************************
 * @brief      Enable GPIO pin pull-up
 *
 * @param[in]  ePinNum :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eChannel:  GPIO pin channel, should be GPIO_PinMuxChannelEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_EnablePullUp(ePinNum,eChannel)     (PINMUX_GPIO(ePinNum)->bit.PU |= (0x01U << eChannel))




/******************************************************************************
 * @brief      Disable GPIO pin pull-up
 *
 * @param[in]  ePinNum :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eChannel:  GPIO pin channel, should be GPIO_PinMuxChannelEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_DisablePullUp(ePinNum,eChannel)    (PINMUX_GPIO(ePinNum)->bit.PU &= (~(0x01U << eChannel)))




/******************************************************************************
 * @brief      Enable GPIO pin pull-down
 *
 * @param[in]  ePinNum :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eChannel:  GPIO pin channel, should be GPIO_PinMuxChannelEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_EnablePullDown(ePinNum,eChannel)     (PINMUX_GPIO(ePinNum)->bit.PD |= (0x01U << eChannel))




/******************************************************************************
 * @brief      Disable GPIO pin pull-down
 *
 * @param[in]  ePinNum :  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eChannel:  GPIO pin channel, should be GPIO_PinMuxChannelEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_DisablePullDown(ePinNum,eChannel)    (PINMUX_GPIO(ePinNum)->bit.PD &= (~(0x01U << eChannel)))




/******************************************************************************
 * @brief      Enable GPIO pin deglitch filter
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_EnableDeglitch(ePinNum)        (PINMUX_GPIO(ePinNum)->bit.DEGLITCH = 1)




/******************************************************************************
 * @brief      Disable GPIO pin deglitch filter
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_DisableDeglitch(ePinNum)       (PINMUX_GPIO(ePinNum)->bit.DEGLITCH = 0)




/******************************************************************************
 * @brief      Set GPIO pin deglitch window size
 *
 * @param[in]  eWindow:  Deglitch clock divider
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_SetDeglitchWindow(u32DIV)     (CLOCK->DGCLKCTL.all = (u32DIV))




/******************************************************************************
 * @brief      Set GPIO pin output
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 * @param[in]  eBitVal:  Value to be written to GPIO pin, should be GPIO_LevelEnum
 *                        - \ref GPIO_LEVEL_LOW
 *                        - \ref GPIO_LEVEL_HIGH
 *
 * @return     none
 *
 ******************************************************************************/
#define __GPIO_OUTPUT_REG_ADDR(ePinNum,bitVal)  ((uint32_t)(GPIO_BASE + 0x24U + (__GPIO_PIN_PORT(ePinNum) << 2) - (bitVal * 12)))
#define GPIO_WritePin(ePinNum,bitVal)           (*(volatile uint32_t*)(__GPIO_OUTPUT_REG_ADDR(ePinNum,bitVal)) = (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Read GPIO pin level
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     Value read from GPIO pin
 *             - \ref 0 : GPIO level is LOW
 *             - \ref 1 : GPIO level is HIGH
 *
 ******************************************************************************/
#define __GPIO_GPLR_ADDR(ePinNum)           ((uint32_t)(GPIO_BASE + (__GPIO_PIN_PORT(ePinNum) << 2)))
#define GPIO_ReadPin(ePinNum)               ((GPIO->GPLR[__GPIO_PIN_PORT(ePinNum)].all & (0x01U << __GPIO_PIN_INDEX(ePinNum)))? (1U) : (0U))
#define GPIO_ReadPinBitBand(ePinNum)        REG_BIT(__GPIO_GPLR_ADDR(ePinNum), __GPIO_PIN_INDEX(ePinNum))



/******************************************************************************
 * @brief      Toggle GPIO pin output value
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_TogglePin(ePinNum)             (GPIO->GPLR[__GPIO_PIN_PORT(ePinNum)].all ^= (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Enable GPIO edge detect
 *
 * @param[in]  pinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_EnableEdgeInt(ePinNum)         (GPIO->GEIE[__GPIO_PIN_PORT(ePinNum)].all |= (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Disable GPIO edge detect
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_DisableEdgeInt(ePinNum)        (GPIO->GEIE[__GPIO_PIN_PORT(ePinNum)].all &= (~(0x01U << __GPIO_PIN_INDEX(ePinNum))))




/******************************************************************************
 * @brief      Get GPIO edge detect status
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     0 - No detected rising or falling edge
 *             1 - Edge was detected on the selected pin
 *
 ******************************************************************************/
#define GPIO_GetEdgeIntStatus(ePinNum)      ((GPIO->GEDR[__GPIO_PIN_PORT(ePinNum)].all & (0x01U << __GPIO_PIN_INDEX(ePinNum)))? (1U) : (0U))




/******************************************************************************
 * @brief      Clear GPIO edge detect status
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_ClearEdgeInt(ePinNum)          (GPIO->GEDR[__GPIO_PIN_PORT(ePinNum)].all = (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Enable GPIO level triggered interrupt
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_EnableLevelInt(ePinNum)        (GPIO->GLIE[__GPIO_PIN_PORT(ePinNum)].all |= (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Disable GPIO level triggered interrupt
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_DisableLevelInt(ePinNum)       (GPIO->GLIE[__GPIO_PIN_PORT(ePinNum)].all &= (~(0x01U << __GPIO_PIN_INDEX(ePinNum))))




/******************************************************************************
 * @brief      Clear GPIO level triggered interrupt
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_ClearLevelInt(ePinNum)         (GPIO->GLIC[__GPIO_PIN_PORT(ePinNum)].all = (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Force level triggered interrupt
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_ForceLevelInt(ePinNum)         (GPIO->GLIFRC[__GPIO_PIN_PORT(ePinNum)].all = (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Interrupt triggered when GPIO level is high
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_SetLevelIntActiveHigh(ePinNum) (GPIO->GLIPOL[__GPIO_PIN_PORT(ePinNum)].all |= (0x01U << __GPIO_PIN_INDEX(ePinNum)))




/******************************************************************************
 * @brief      Interrupt triggered when GPIO level is low
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_SetLevelIntActiveLow(ePinNum)  (GPIO->GLIPOL[__GPIO_PIN_PORT(ePinNum)].all &= (~(0x01U << __GPIO_PIN_INDEX(ePinNum))))




/******************************************************************************
 * @brief      Get level triggered interrupt polarity
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     0 - Interrupt triggered when GPIO level is HIGH
 *             1 - Interrupt triggered when GPIO level is LOW
 *
 ******************************************************************************/
#define GPIO_GetLevelIntPol(ePinNum)        ((GPIO->GLIPOL[__GPIO_PIN_PORT(ePinNum)].all & (0x01U << __GPIO_PIN_INDEX(ePinNum)))? (1U) : (0U))




/******************************************************************************
 * @brief      Get level triggered interrupt status
 *
 * @param[in]  ePinNum:  Select the GPIO pin, should be GPIO_PinEnum
 *
 * @return     0 - No level interrupt was detected
 *             1 - A level interrupt was detected
 *
 ******************************************************************************/
#define GPIO_GetLevelIntStatus(ePinNum)     ((GPIO->GLIF[__GPIO_PIN_PORT(ePinNum)].all & (0x01U << __GPIO_PIN_INDEX(ePinNum)))? (1U) : (0U))




/******************************************************************************
 * @brief      Get GPIO edge-triggered interrupt flag
 *
 * @param[in]  none
 *
 * @return     0 - No edge-triggered interrupt occurred
 *             1 - Edge-triggered interrupt occurred
 *
 ******************************************************************************/
#define GPIO_GetGlobalEdgeIntStatus()       (GPIO->GIF.bit.EDGE)




/******************************************************************************
 * @brief      Get GPIO level-triggered interrupt flag
 *
 * @param[in]  none
 *
 * @return     0 - No detected rising or falling edge
 *             1 - Edge was detected
 *
 ******************************************************************************/
#define GPIO_GetGlobalLevelIntStatus()      (GPIO->GIF.bit.LEVEL)




/******************************************************************************
 * @brief      Clear GPIO edge-triggered interrupt flag
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_ClearGlobalEdgeInt()           (GPIO->GIC.all = GIC_ALL_EDGE_CLEAR)




/******************************************************************************
 * @brief      Clear GPIO level-triggered interrupt flag
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_ClearGlobalLevelInt()          (GPIO->GIC.all = GIC_ALL_LEVEL_CLEAR)




/******************************************************************************
 * @brief      Enable write access to the protected GPIO registers
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_WALLOW()                      (GPIO->GPIOREGKEY.all = 0x1ACCE551)




/******************************************************************************
 * @brief      Disable write access to the protected GPIO registers
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define GPIO_WDIS()                        (GPIO->GPIOREGKEY.all = 0x0)




/******************************************************************************
 * @brief      Enable write access to the protected PINMUX registers
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define PINMUX_WALLOW()                      (PINMUX->PINMUXREGKEY.all = 0x1ACCE551)




/******************************************************************************
 * @brief      Disable write access to the protected PINMUX registers
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define PINMUX_WDIS()                        (PINMUX->PINMUXREGKEY.all = 0x0)




/**
 *  @brief GPIO Public Function Declaration
 */
void GPIO_ResetAllPin(void);
void GPIO_SetPinAsGPIO(GPIO_PinEnum ePinNum);
void GPIO_SetPinAsAnalog(GPIO_PinEnum ePinNum);

void GPIO_SetPinDir(GPIO_PinEnum ePinNum, GPIO_DirEnum eDir);

void GPIO_SetEdgeIntMode(GPIO_PinEnum ePinNum, GPIO_EdgeIntEnum eIntType);


#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* GPIO_H */


/******************* (C) COPYRIGHT 2021 SPINTROL LIMITED ***** END OF FILE ****/
