/*******************************************************************************
 * @file     mailbox.h
 * @brief    Mailbox driver header file.
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/


#ifndef MAILBOX_H
#define MAILBOX_H

#ifdef __cplusplus
extern "C" {
#endif


#include "spc2168.h"




/******************************************************************************
 * @brief      Main CPU issue an interrupt to CAU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_MainCPUIssueRequestToCAU()    (MAILBOX->M2CINTCTL.all = 0x1)




/******************************************************************************
 * @brief      Main CPU cancle the request to CAU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_MainCPUCancelRequestToCAU()   (MAILBOX->M2CINTCTL.all = 0xCA17CE1)




/******************************************************************************
 * @brief      CAU clear the interrupt come from Main CPU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_CAUClearRequestFromMainCPU()  (MAILBOX->M2CINTCTL.all = 0x1)




/******************************************************************************
 * @brief      CAU issue an interrupt to Main CPU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_CAUIssueRequestToMainCPU()    (MAILBOX->C2MINTCTL.all = 0x1)




/******************************************************************************
 * @brief      CAU cancle the request to Main CPU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_CAUCancelRequestToMainCPU()   (MAILBOX->C2MINTCTL.all = 0xCA17CE1)




/******************************************************************************
 * @brief      Main CPU clear the interrupt come from CAU
 *
 * @param[in]  none
 *
 * @return     none
 *
 ******************************************************************************/
#define MAILBOX_MainCPUClearRequestFromCAU()  (MAILBOX->C2MINTCTL.all = 0x1)




/**
 *  @brief Power Public Function Declaration
 */



#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* MAILBOX_H */


/******************* (C) COPYRIGHT 2021 SPINTROL LIMITED ***** END OF FILE ****/
