/**************************************************************************//**
 * @file     main.c
 * @brief    Main program body
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited Corporation. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING 
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE 
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE 
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/

#include "spc2168.h"
#include <stdio.h>


uint32_t *pu32Src = (uint32_t *)0x20002000;
uint32_t *pu32Dst = (uint32_t *)0x20003000;
uint32_t i;


 /*************************************************************************************************************************
 *
 * @brief       This example use DMA channel 0 to transfer a single block transfer (block transfer length is 13 words), 
 *              after transaction is done, trigger a complete INT, and check the datum.
 *
 *************************************************************************************************************************/


int main()
{
  FLASH_WALLOW();
  FLASH_SetTiming(200000000);
  /* Disable flash write access after flash operation had done */
  FLASH_WDIS();

  CLOCK_InitWithRCO(CLOCK_HCLK_200MHZ);

  Delay_Init();

  /*
   * Init the UART
   *
   * 1.Set the GPIO44/45 as UART FUNC
   *
   * 2.Enable the UART CLK
   *
   * 3.Set the rest para
   */
  GPIO_SetPinChannel(GPIO_44,GPIO44_UART_TXD);
  GPIO_SetPinChannel(GPIO_45,GPIO45_UART_RXD);
  CLOCK_EnableModule(UART_MODULE);
  UART_Init(UART,38400);

  /* Enable global INT for DMA */
  NVIC_EnableIRQ(DMAC_IRQn);
  
  /* Init source memory */
  for(i = 0; i < 16; i++)
  {
    pu32Src[i] = 0x11223344;
  }
  
  /* Enable DMA */
  DMA_Enable();
  
  /* Source address */
  DMA_SetSourceAddr(DMACH0, 0x20002000);
  /* Destination address */
  DMA_SetDestinationAddr(DMACH0, 0x20003000);
  
  /* Transfer type */
  DMA_SetTransferType(DMACH0, DMACHCTL0_BIT_TT_MEM_TO_MEM);
  
  /* Source burst transfer length - 4 words = UART RXFIFO Threshold */
  DMA_SetSourceBurstLen(DMACH0, DMACHCTL0_BIT_SSIZE_4_WORD);
  /* Set destination burst transfer length as the same as Source */
  DMA_SetDestinationBurstLen(DMACH0, DMACHCTL0_BIT_DSIZE_4_WORD);
  
  /* Source address increment */
  DMA_SetSourceAddrMode(DMACH0, DMA_ADDRESS_MODE_INCREASE);
  /* Destination address increment */
  DMA_SetDestinationAddrMode(DMACH0, DMA_ADDRESS_MODE_INCREASE);
  
  /* Block transfer size */
  DMA_SetBlockTransferSize(DMACH0, 13);
  
  /* Enable channel 0 interruput */
  DMA_EnableChannelInt(DMACH0);
  /* Enable Channel 0 transfer complete interrupt */
  DMA_EnableTransferCompleteInt(DMA_CH0);
  
  /* Enable Channel 0 */
  DMA_EnableChannelTransfer(DMA_CH0);

  while(1)
  {

  }
}

void DMAC_IRQHandler(void)
{
  if(DMA_GetErrorGlobalIntFlag() == 1)
  {
    printf("DMA Channel Error!\n");
  }
  
  if(DMA_GetTransferCompleteGlobalIntFlag() == 1)
  {
    printf("Channel transfer complete!\n");
  }
  
  if(DMA_GetTransferCompleteIntFlag(DMA_CH0) == 1)
  {
    printf("Channel 0 transfer complete!\n");
    
    for(i = 0; i < 20; i++)
    {
      printf("Dest[%d] = 0x%08X\n", i , pu32Dst[i]);
    }
    
    DMA_ClearTransferCompleteInt(DMA_CH0);
  }
}
