/**************************************************************************//**
 * @file     main.c
 * @brief    Main program body
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited Corporation. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING 
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE 
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE 
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/

#include "spc2168.h"
#include <stdio.h>


 /*************************************************************************************************************************
 *
 * @brief      This demo is couple with 'DualCore_MainCPU_ToggleGPIO', they work together, MainCPU set the GPIO41 low, then
 *             sent a message('555' or '100') to CAU,and trigger a interruput to CAU, int the IRQhandle of CAU, clear the 
 *             interruput and read the message first, and set the GPIO41 level refer to the message, and then trigger a 
 *             interruput back to MainCPU, in the MainCPU IRQhandle, clear the interruput which comes from CAU, and read the 
 *             message sent by the CAU. after that, MainCPU and CAU turn to the next cycle.
 *
 *
 *                       ---------------------
 *                      |                     |                             RAM(belong to CAU)
 *                      |---------------------|                           -------------------  0x1FFFBFFF(in CPU perspective) / 0x3FFF(in CAU perspective)
 *                      |  CAU executable file|------------------------->|                   |
 *                      |---------------------| 0x10020000               |                   |
 *                      |                     |                          |                   |
 *                      |                     |                           -------------------  0x1FFF8000(in CPU perspective) / 0x0(in CAU perspective)
 *                      |---------------------|
 *                      |  CPU executable file|
 *                      |---------------------| 0x10000000
 *                      |                     |
 *                       ---------------------
 *              MainCPU Process step :
 *                         <1> The CAU executable file is loaded to 0x10020000 and CPU executable file is loaded to 0x10000000.
 *                         <2> After CUP is working, the CAU executable file will be copied to RAM belonged to CAU. 
 *                         <3> Then CAU will be enable.
 *                         <4> After CAU power up, it will execut instruction from 0x1FFF8000 (the start address of the RAM
 *                             belonging to CAU in CPU perspective, in CAU own perspective, the address is 0x0, so the 
 *                             excutable start address is 0x0 in the project target configuration.)
 *             
 *              Key Point :
 *                         <1> Make sure the chip has CAU and XIP cache.
 *                         <2> The CAU executable file is loaded to 0x10020000 by default, change or not is upon you.
 *                         <3> If your chip had no cache, you need to change u32AddrDst from 0x1FFF8000 to 0x1FFF4000.
 *
 *************************************************************************************************************************/


int main()
{
  NVIC_EnableIRQ(MAILBOX_IRQn);
  printf("CAU -> CAU Running\n\n");
  
  /* Set GPIO42 as GPIO output */
  GPIO_SetPinChannel(GPIO_42, GPIO42_GPIO42);
  GPIO_SetPinDir(GPIO_42, GPIO_OUTPUT);

  while(1)
  {

  }
}
