/**************************************************************************//**
 * @file     main.c
 * @brief    Main program body
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited Corporation. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING 
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE 
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE 
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/

#include "spc2168.h"
#include <stdio.h>


uint32_t i;
uint32_t u32AddrSrc, u32AddrDst;
uint32_t *pu32DataSrc, *pu32DataDst;


/* Copy (u32Size * 4) bytes datum from 'pu32SourceAddr' to 'pu32DestinationAddr' */
void CAU_CodeInit(uint32_t pu32SourceAddr, uint32_t pu32DestinationAddr, uint32_t u32Size)
{
  for(i = 0; i < u32Size; i++)
  {
    pu32DataSrc = (uint32_t*)pu32SourceAddr;
    pu32DataDst = (uint32_t*)pu32DestinationAddr;
    
    *pu32DataDst = *pu32DataSrc;
    
    pu32SourceAddr += 4;
    pu32DestinationAddr += 4;
  }
}


 /*************************************************************************************************************************
 *
 * @brief      This demo is couple with 'DualCore_CAU_ToggleGPIO', they work together, MainCPU set the GPIO41 low, then 
 *             sent a message('555' or '100') to CAU,and trigger a interruput to CAU, int the IRQhandle of CAU, clear the 
 *             interruput and read the message first, and set the GPIO41 level refer to the message, and then trigger a 
 *             interruput back to MainCPU, in the MainCPU IRQhandle, clear the interruput which comes from CAU, and read the 
 *             message sent by the CAU. after that, MainCPU and CAU turn to the next cycle.
 *
 *
 *                       ---------------------
 *                      |                     |                               RAM(belong to CAU)
 *                      |---------------------|                           -------------------  0x1FFFBFFF(in CPU perspective) / 0x3FFF(in CAU perspective)
 *                      |  CAU executable file|------------------------->|                   |
 *                      |---------------------| 0x10020000               |                   |
 *                      |                     |                          |                   |
 *                      |                     |                           -------------------  0x1FFF8000(in CPU perspective) / 0x0(in CAU perspective)
 *                      |---------------------|
 *                      |  CPU executable file|
 *                      |---------------------| 0x10000000
 *                      |                     |
 *                       ---------------------
 *             MainCPU Process step :
 *                        <1> The CAU executable file is loaded to 0x10020000 and CPU executable file is loaded to 0x10000000.
 *                        <2> After CUP is working, the CAU executable file will be copied to RAM belonged to CAU. 
 *                        <3> Then CAU will be enable.
 *                        <4> After CAU power up, it will execut instruction from 0x1FFF8000 (the start address of the RAM
 *                            belonging to CAU)
 *            
 *             Key Point :
 *                        <1> Make sure the chip has CAU and XIP cache.
 *                        <2> The CAU executable file is loaded to 0x10020000 by default, change or not is upon you.
 *                        <3> If your chip had no cache, you need to change u32AddrDst from 0x1FFF8000 to 0x1FFF4000.
 *
 *************************************************************************************************************************/


int main()
{
  FLASH_WALLOW();
  FLASH_SetTiming(200000000);
  /* Disable flash write access after flash operation had done */
  FLASH_WDIS();

  CLOCK_InitWithRCO(CLOCK_HCLK_200MHZ);

  Delay_Init();

  /*
   * Init the UART
   *
   * 1.Set the GPIO44/45 as UART FUNC
   *
   * 2.Enable the UART CLK
   *
   * 3.Set the rest para
   */
  GPIO_SetPinChannel(GPIO_44,GPIO44_UART_TXD);
  GPIO_SetPinChannel(GPIO_45,GPIO45_UART_RXD);
  CLOCK_EnableModule(UART_MODULE);
  UART_Init(UART,38400);
  
  NVIC_EnableIRQ(MAILBOX_IRQn);
  
  printf("MCPU-> Loade CAU Code\n");
  
  u32AddrSrc = 0x10020000;
  u32AddrDst = 0x1FFF8000;
  
  /* Code is initially in flash. Need to copy to the CAU code-RAM before running */
  CAU_CodeInit(u32AddrSrc, u32AddrDst, 1024);
  
  printf("MCPU-> Enable CAU Run\n");
  SYSTEM_EnableCAU();
  
  /* Set GPIO41 as GPIO output */
  GPIO_SetPinChannel(GPIO_41, GPIO41_GPIO41);
  GPIO_SetPinDir(GPIO_41, GPIO_OUTPUT);
  
  while(1)
  {
    for(i = 0; i < 100000; i++);
    GPIO_WritePin(GPIO_41, GPIO_LEVEL_LOW);

    /* Set the message that MainCPU send to CAU */
    MAILBOX->M2CMSG[0].all = (555);
    
    /* Trigger an interrupt to CAU */
    MAILBOX_MainCPUIssueRequestToCAU();
    
    for(i = 0; i < 100000; i++);
    GPIO_WritePin(GPIO_41, GPIO_LEVEL_HIGH);
    
    /* Set the message that MainCPU send to CAU */
    MAILBOX->M2CMSG[0].all = (100);
    
    /* Trigger an interrupt to CAU */
    MAILBOX_MainCPUIssueRequestToCAU();
  }
}
